@@ -14,13 +14,16 @@ from mdast_cli.distribution_systems.firebase import firebase_download_app
 from mdast_cli.distribution_systems.google_play import GooglePlay
 from mdast_cli.distribution_systems.nexus import NexusRepository
 from mdast_cli.distribution_systems.nexus2 import Nexus2Repository
+from mdast_cli.distribution_systems.rumarket import rumarket_download_app
 from mdast_cli.distribution_systems.rustore import rustore_download_app
 from mdast_cli.helpers.const import (ANDROID_EXTENSIONS, END_SCAN_TIMEOUT, LONG_TRY, SLEEP_TIMEOUT, TRY, DastState,
                                      DastStateDict)
 from mdast_cli.helpers.helpers import check_app_md5
 from mdast_cli_core.token import mDastToken as mDast
+from mdast_cli.cr_report_generator import generate_cr
 
-logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(levelname)s %(message)s', datefmt='%d/%m/%Y %H:%M:%S')
+logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(levelname)s %(message)s',
+                    datefmt='%d/%m/%Y %H:%M:%S', stream=sys.stdout)
 
 logger = logging.getLogger(__name__)
 
@@ -31,10 +34,10 @@ def parse_args():
                                                                            'without scan.'
                                                                            ' This argument is optional')
     parser.add_argument('--distribution_system', '-ds', type=str, help='Select how to download file: '
-                                                                       'file/appcenter/nexus'
-                                                                       '/firebase/appstore/google_play/rustore',
+                                                                       'file/appcenter/nexus/firebase/'
+                                                                       'appstore/google_play/rustore/rumarket',
                         choices=['file', 'appcenter', 'nexus', 'nexus2', 'firebase', 'appstore', 'google_play',
-                                 'rustore', 'appgallery'],
+                                 'rustore', 'appgallery', 'rumarket'],
                         required=True)
 
     # Arguments used for distribution_system = file
@@ -141,9 +144,14 @@ def parse_args():
                         help='Google auth token for access to Google Play API. '
                              'You should get it from console logs during first login attempt with email and password.'
                              ' This argument required if distribution system set to "google_play"')
+    parser.add_argument('--google_play_vc_null', action='store_true', default=None,
+                        help='Google play app version code = '', optional, use if DF-DFERH-01 when vc=None ')
     parser.add_argument('--google_play_file_name', type=str,
                         help='File name for downloaded application.'
                              ' This argument is optional if distribution system set to "google_play"')
+    parser.add_argument('--google_play_proxy', type=str,
+                        help='Proxy config for Google Play'
+                             ' This argument is optional if distribution system set to "google_play"')
     parser.add_argument('--google_play_download_with_creds', action='store_true',
                         help='Download the application at the first login with email + password. '
                              'This argument is optional if distribution system set to "google_play"')
@@ -153,6 +161,11 @@ def parse_args():
                         help='Application package name from Rustore. This argument is required if '
                              'distribution system set to "rustore"')
 
+    # Arguments for Rustore
+    parser.add_argument('--rumarket_package_name', type=str,
+                        help='Application package name from Rumarket. This argument is required if '
+                             'distribution system set to "rumarket"')
+
     # Arguments for Appgallery
     parser.add_argument('--appgallery_app_id', type=str,
                         help='Application id from Appgallery. This argument is required if '
@@ -212,6 +225,20 @@ def parse_args():
                         default='downloaded_apps')
     parser.add_argument('--long_wait', action='store_true', help='Time limit - 1 week for scan finish')
 
+    parser.add_argument('--cr_report', action='store_true', help='Generate CR report for scan')
+    parser.add_argument('--stingray_login', type=str, help='Stingray login for CR report. Required if --cr_report.')
+    parser.add_argument('--stingray_password', type=str, help='Stingray password for CR report. Required if --cr_report.')
+    parser.add_argument('--organization_name', type=str, help='Organization name for CR report.', default='ООО Стингрей Технолоджиз')
+    parser.add_argument('--engineer_name', type=str, help='Engineer name for CR report.')
+    parser.add_argument('--controller_name', type=str, help='Controller name for CR report.')
+    parser.add_argument('--use_ldap', type=str, help='Use LDAP for CR report.', default=False)
+    parser.add_argument('--authority_server_id', type=str, help='Authority server id for CR report.', default=None)
+    parser.add_argument('--cr_report_path', type=str, help='Use LDAP for CR report.', default='stingray-CR-report.html')
+
+
+
+
+
     args = parser.parse_args()
 
     if args.distribution_system == 'file' and args.file_path is None:
@@ -277,6 +304,9 @@ def parse_args():
     elif args.distribution_system == 'rustore' and args.rustore_package_name is None:
         parser.error('"--distribution_system rustore" requires "--rustore_package_name" to be set')
 
+    elif args.distribution_system == 'rumarket' and args.rumarket_package_name is None:
+        parser.error('"--distribution_system rumarket" requires "--rumarket_package_name" to be set')
+
     elif args.distribution_system == 'appgallery' and args.appgallery_app_id is None:
         parser.error('"--distribution_system appgallery" requires "--appgallery_app_id" to be set')
 
@@ -304,6 +334,16 @@ def main():
         pdf_report_file_name = arguments.pdf_report_file_name
         not_wait_scan_end = arguments.nowait
         long_wait = arguments.long_wait
+        cr_report = arguments.cr_report
+        stingray_login = arguments.stingray_login
+        stingray_password = arguments.stingray_password
+        organization_name = arguments.organization_name
+        engineer_name = arguments.engineer_name
+        controller_name = arguments.controller_name
+        use_ldap = arguments.use_ldap
+        authority_server_id = arguments.authority_server_id
+        cr_report_path = arguments.cr_report_path
+
 
         url = url if url.endswith('/') else f'{url}/'
         url = url if url.endswith('rest/') else f'{url}rest'
@@ -375,13 +415,17 @@ def main():
                 exit(0)  # just get token and exit
 
             app_file = google_play.download_app(download_path,
-                                                arguments.google_play_package_name,
-                                                arguments.google_play_file_name)
+                                                arguments.google_play_package_name, arguments.google_play_vc_null,
+                                                arguments.google_play_file_name, proxy=arguments.google_play_proxy)
 
         elif distribution_system == 'rustore':
             package_name = arguments.rustore_package_name
             app_file = rustore_download_app(package_name, download_path)
 
+        elif distribution_system == 'rumarket':
+            package_name = arguments.rumarket_package_name
+            app_file = rumarket_download_app(package_name, download_path)
+
         elif distribution_system == 'appgallery':
             app_file = appgallery_download_app(arguments.appgallery_app_id,
                                                download_path,
@@ -425,6 +469,10 @@ def main():
             logger.warning("Testcase with this id does not exist or you use old version of system. Trying to use "
                            "architecture from command line params.")
 
+    if sum(e['architecture'] == architecture_type['id'] and e['state'] == 3 for e in mdast.get_engines().json()) == 0:
+        logger.error(f"Cannot create scan - Cannot find active engine for architecture {architecture_type['name']}")
+        sys.exit(1)
+
     if testcase_id:
         logger.info(f'Autoscan(Stingray) with test case id: '
                     f'{testcase_id}, profile id: {profile_id} and file: {app_file}, architecture id is {architecture}')
@@ -456,10 +504,10 @@ def main():
         logger.info(f"Application uploaded successfully. Application id: {application['id']}")
 
     logger.info(f"Creating scan for application {application['id']}")
-    if testcase_id:
+    if testcase_id is not None:
         create_dast_resp = mdast.create_auto_scan(project_id, profile_id, application['id'], architecture, testcase_id)
         scan_type = 'auto_stingray'
-    elif appium_script_path:
+    elif appium_script_path is not None:
         create_dast_resp = mdast.create_appium_scan(project_id, profile_id, application['id'], architecture,
                                                     appium_script_path)
         scan_type = 'auto_appium'
@@ -606,10 +654,10 @@ def main():
 
     if json_summary_file_name:
         logger.info(
-            f"Create and download JSON summary report for scan with id {dast['id']} to file {json_summary_file_name}.")
-        json_summary_report = mdast.get_scan_info(dast['id'])
+            f"Download JSON summary report for scan with id {dast['id']} to file {json_summary_file_name}.")
+        json_summary_report = mdast.download_scan_json_result(dast['id'])
         if json_summary_report.status_code != 200:
-            logger.error(f"JSON summary report creating failed with error {json_summary_report.text}. Exit...")
+            logger.error(f"JSON summary report while downloading failed with error {json_summary_report.text}. Exit...")
             sys.exit(1)
 
         logger.info(f"Saving summary json results to file {json_summary_file_name}.")
@@ -620,6 +668,10 @@ def main():
 
         logger.info(f"JSON report for scan {dast['id']} successfully created and available at path: {mdast_json_file}.")
 
+    if cr_report:
+        generate_cr(f"{url}", stingray_login, stingray_password, dast['id'], organization_name, engineer_name,
+                    controller_name, cr_report_path, use_ldap, authority_server_id)
+
     logger.info('Job completed successfully!')
 
 
